;; -*- lexical-binding: t; -*-
(require 'spacemacs-theme)

(deftheme spacemacs-light "Spacemacs theme, the light version")

(create-spacemacs-theme 'light 'spacemacs-light)

(provide-theme 'spacemacs-light)
